@@ -5,8 +5,8 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2007 Jari-Matti Mäkelä <jmjm@iki.fi>                    *
- *   copyright (C) 2008-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
+ *   copyright (C) 2008-2013                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -28,8 +28,8 @@
 #include "dcodeclassfield.h"
 #include "dcodedocumentation.h"
 
-DCodeAccessorMethod::DCodeAccessorMethod (CodeClassField * field, CodeAccessorMethod::AccessorType type)
-        : CodeAccessorMethod (field)
+DCodeAccessorMethod::DCodeAccessorMethod ( CodeClassField * field, CodeAccessorMethod::AccessorType type)
+        : CodeAccessorMethod ( field )
 {
     setType(type);
 
@@ -38,11 +38,11 @@ DCodeAccessorMethod::DCodeAccessorMethod (CodeClassField * field, CodeAccessorMe
     setComment(new DCodeDocumentation(jccd));
 }
 
-DCodeAccessorMethod::~DCodeAccessorMethod ()
+DCodeAccessorMethod::~DCodeAccessorMethod ( )
 {
 }
 
-void DCodeAccessorMethod::setAttributesOnNode (QDomDocument & doc, QDomElement & blockElement)
+void DCodeAccessorMethod::setAttributesOnNode ( QDomDocument & doc, QDomElement & blockElement)
 {
     // set super-class attributes
     CodeAccessorMethod::setAttributesOnNode(doc, blockElement);
@@ -50,7 +50,7 @@ void DCodeAccessorMethod::setAttributesOnNode (QDomDocument & doc, QDomElement &
     // set local attributes now
 }
 
-void DCodeAccessorMethod::setAttributesFromNode(QDomElement & root)
+void DCodeAccessorMethod::setAttributesFromNode( QDomElement & root)
 {
     // set attributes from superclass method the XMI
     CodeAccessorMethod::setAttributesFromNode(root);
@@ -58,13 +58,13 @@ void DCodeAccessorMethod::setAttributesFromNode(QDomElement & root)
     // load local stuff
 }
 
-void DCodeAccessorMethod::updateContent()
+void DCodeAccessorMethod::updateContent( )
 {
     CodeClassField * parentField = getParentClassField();
     DCodeClassField * dfield = dynamic_cast<DCodeClassField*>(parentField);
     QString fieldName = dfield->getFieldName();
 
-    QString text;
+    QString text = "";
     switch(getType()) {
     case CodeAccessorMethod::ADD:
         {
@@ -73,20 +73,20 @@ void DCodeAccessorMethod::updateContent()
             QString indent = getIndentation();
             QString endLine = UMLApp::app()->commonPolicy()->getNewLineEndingChars();
             if(maxOccurs > 0)
-                text += QLatin1String("if (") + fieldName + QLatin1String(".size() < ")+ QString::number(maxOccurs) + QLatin1String(") {") + endLine + indent;
-            text += fieldName + QLatin1String(".add(value);");
+                text += "if ("+fieldName+".size() < "+ QString::number(maxOccurs)+") {"+endLine+indent;
+            text += fieldName+".add(value);";
             if(maxOccurs > 0)
             {
-                text += endLine + QLatin1String("} else {") + endLine;
-                text += indent + QLatin1String("System.err.println(\"ERROR: Cant add") + fieldType + QLatin1String(" to ") + fieldName + QLatin1String(", minimum number of items reached.\");") + endLine + QLatin1Char('}') + endLine;
+                text += endLine+"} else {"+endLine;
+                text += indent + "System.err.println(\"ERROR: Cant add"+fieldType+" to "+fieldName+", minimum number of items reached.\");"+endLine+'}'+endLine;
             }
             break;
         }
     case CodeAccessorMethod::GET:
-        text = QLatin1String("return ") + fieldName + QLatin1Char(';');
+        text = "return "+fieldName+';';
         break;
     case CodeAccessorMethod::LIST:
-        text = QLatin1String("return (List) ") + fieldName + QLatin1Char(';');
+        text = "return (List) "+fieldName+';';
         break;
     case CodeAccessorMethod::REMOVE:
         {
@@ -96,17 +96,17 @@ void DCodeAccessorMethod::updateContent()
             QString indent = getIndentation();
 
             if(minOccurs > 0)
-                text += QLatin1String("if (") + fieldName + QLatin1String(".size() >= ")+ QString::number(minOccurs) + QLatin1String(") {") + endLine + indent;
-            text += fieldName + QLatin1String(".remove(value);");
+                text += "if ("+fieldName+".size() >= "+ QString::number(minOccurs)+") {"+endLine+indent;
+            text += fieldName+".remove(value);";
             if(minOccurs > 0)
             {
-                text += endLine + QLatin1String("} else {") + endLine;
-                text += indent + QLatin1String("System.err.println(\"ERROR: Cant remove") + fieldType + QLatin1String(" from ") + fieldName + QLatin1String(", minimum number of items reached.\");") + endLine + QLatin1Char('}') + endLine;
+                text += endLine+"} else {"+endLine;
+                text += indent + "System.err.println(\"ERROR: Cant remove"+fieldType+" from "+fieldName+", minimum number of items reached.\");"+endLine+'}'+endLine;
             }
             break;
         }
     case CodeAccessorMethod::SET:
-        text = fieldName + QLatin1String(" = value;");
+        text = fieldName+" = value;";
         break;
     default:
         // do nothing
@@ -148,39 +148,39 @@ void DCodeAccessorMethod::updateMethodDeclaration()
     }
 
     // some variables we will need to populate
-    QString headerText;
-    QString methodReturnType;
-    QString methodName;
-    QString methodParams;
+    QString headerText = "";
+    QString methodReturnType = "";
+    QString methodName = "";
+    QString methodParams = "";
 
     switch(getType()) {
     case CodeAccessorMethod::ADD:
-        methodName = QLatin1String("add") + Codegen_Utils::capitalizeFirstLetter(fieldType);
-        methodReturnType = QLatin1String("void");
-        methodParams = objectType + QLatin1String(" value ");
-        headerText = QLatin1String("Add an object of type ") + objectType + QLatin1String(" to the List ") + fieldName + endLine + getParentObject()->doc() + endLine + QLatin1String("@return void");
+        methodName = "add" + Codegen_Utils::capitalizeFirstLetter(fieldType);
+        methodReturnType = "void";
+        methodParams = objectType+" value ";
+        headerText = "Add an object of type "+objectType+" to the List "+fieldName+endLine+getParentObject()->doc()+endLine+"@return void";
         break;
     case CodeAccessorMethod::GET:
-        methodName = QLatin1String("get") + Codegen_Utils::capitalizeFirstLetter(fieldName);
+        methodName = "get" + Codegen_Utils::capitalizeFirstLetter(fieldName);
         methodReturnType = fieldType;
-        headerText = QLatin1String("Get the value of ") + fieldName + endLine + getParentObject()->doc() + endLine + QLatin1String("@return the value of ") + fieldName;
+        headerText = "Get the value of "+fieldName+endLine+getParentObject()->doc()+endLine+"@return the value of "+fieldName;
         break;
     case CodeAccessorMethod::LIST:
-        methodName = QLatin1String("get") + Codegen_Utils::capitalizeFirstLetter(fieldType) + QLatin1String("List");
-        methodReturnType = QLatin1String("List");
-        headerText = QLatin1String("Get the list of ") + fieldName + endLine + getParentObject()->doc() + endLine + QLatin1String("@return List of ") + fieldName;
+        methodName = "get" + Codegen_Utils::capitalizeFirstLetter(fieldType)+"List";
+        methodReturnType = "List";
+        headerText = "Get the list of "+fieldName+endLine+getParentObject()->doc()+endLine+"@return List of "+fieldName;
         break;
     case CodeAccessorMethod::REMOVE:
-        methodName = QLatin1String("remove") + Codegen_Utils::capitalizeFirstLetter(fieldType);
-        methodReturnType = QLatin1String("void");
-        methodParams = objectType + QLatin1String(" value ");
-        headerText = QLatin1String("Remove an object of type ") + objectType + QLatin1String(" from the List ") + fieldName + endLine + getParentObject()->doc();
+        methodName = "remove" + Codegen_Utils::capitalizeFirstLetter(fieldType);
+        methodReturnType = "void";
+        methodParams = objectType+" value ";
+        headerText = "Remove an object of type "+objectType+" from the List "+fieldName+endLine+getParentObject()->doc();
         break;
     case CodeAccessorMethod::SET:
-        methodName = QLatin1String("set") + Codegen_Utils::capitalizeFirstLetter(fieldName);
-        methodReturnType = QLatin1String("void");
-        methodParams = fieldType + QLatin1String(" value ");
-        headerText = QLatin1String("Set the value of ") + fieldName + endLine + getParentObject()->doc() + endLine;
+        methodName = "set" + Codegen_Utils::capitalizeFirstLetter(fieldName);
+        methodReturnType = "void";
+        methodParams = fieldType + " value ";
+        headerText = "Set the value of "+fieldName+endLine+getParentObject()->doc()+endLine;
         break;
     default:
         // do nothing..no idea what this is
@@ -193,8 +193,8 @@ void DCodeAccessorMethod::updateMethodDeclaration()
         getComment()->setText(headerText);
 
     // set start/end method text
-    setStartMethodText(strVis + QLatin1Char(' ') + methodReturnType + QLatin1Char(' ') + methodName + QLatin1String(" (") + methodParams + QLatin1String(") {"));
-    setEndMethodText(QLatin1String("}"));
+    setStartMethodText(strVis+' '+methodReturnType+' '+methodName+" ( "+methodParams+" ) {");
+    setEndMethodText("}");
 }
 
 void DCodeAccessorMethod::update()
@@ -203,3 +203,4 @@ void DCodeAccessorMethod::update()
     updateContent();
 }
 
+#include "dcodeaccessormethod.moc"
